@@ -73,7 +73,7 @@ void CameraWidget::on_ButtonPicture_clicked()
 
     QProcess process;
 
-    process.startDetached(" gst-launch v4l2src device=/dev/video0 num-buffers=1 ! dspjpegenc ! filesink location=/usr/share/doc/poza.jpg");
+    process.startDetached(" gst-launch v4l2src device=/dev/video0 num-buffers=1 ! dspjpegenc ! filesink location=/home/opt/phototranslator-alpha/poza.jpg");
 
     sleep(3);
  //   QString strFile = "/usr/share/doc/poza.jpg";
